#
# spec file for package python-yamllint
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-yamllint
Version:        1.22.1
Release:        lp152.1.1
Summary:        A linter for YAML files
License:        GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/adrienverge/yamllint
Source:         https://files.pythonhosted.org/packages/source/y/yamllint/yamllint-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-pathspec >= 0.5.3
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pathspec >= 0.5.3}
# /SECTION
%python_subpackages

%description
A linter for YAML files.

YAMLlint does not only check for syntax validity, but for weirdnesses like key
repetition and cosmetic problems such as lines length, trailing spaces,
indentation, etc.

%prep
%setup -q -n yamllint-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/yamllint

%check
export LANG="en_US.UTF8"
%python_exec -m unittest discover -v

%post
%python_install_alternative yamllint

%postun
%python_uninstall_alternative yamllint

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/yamllint
%{python_sitelib}/*

%changelog
* Thu Apr 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.22.1:
  * Fix quoted-strings rule with only-when-needed on corner cases
  * Add check-keys option to the truthy rule
  * Fix quoted-strings rule not working on sequences items
  * Sunset Python 2
  * Fix new-lines rule on Python 3 with DOS line endings
  * Fix quoted-strings rule not working for string values matching scalars
  * Add required: only-when-needed option to the quoted-strings rule
* Tue Feb  4 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.20.0
  * Add --no-warnings option to suppress warning messages
  * Use 'syntax' as rule name upon syntax errors
  * Allow disabling all checks for a file with # yamllint disable-file
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.18.0:
  * Lint .yamllint config file by default
  * Also read config from .yamllint.yml and .yamllint.yaml
  * Improve documentation for yaml-files
  * Update documentation for pre-commit
  * Explicitly disable empty-values and octal-values rules
* Mon Aug 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.17.0:
  * Simplify installation instructions in the README
  * Add OpenBSD installation instructions
  * Make YAML file extensions configurable
* Fri Jun 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.16.0
  * Add the allowed-values option to the truthy rule
  * Allow configuration options to be a list of enums
* Thu Feb 14 2019 John Vandenberg <jayvdb@gmail.com>
- Update to 1.15.0
  * Add command line option - to read from standard input
- Disable a flaky test caused by PyYAML
* Mon Feb 11 2019 John Vandenberg <jayvdb@gmail.com>
- Update to 1.14.0
  * Fix documentation code snippets
  * Drop Python 2.6 and 3.3 support, add Python 3.7 support
  * Update documentation and tests for ``line-length`` + Unicode + Python 2
  * Allow rule configurations to lack options
  * Add a new ``ignore-shebangs`` option for the ``comments`` rule
* Sun Dec 30 2018 John Vandenberg <jayvdb@gmail.com>
- Update to 1.13.0
  * Add a new -f colored option
- Update to 1.12.1
  * Fix the `quoted-strings` rule
- Update to 1.12.0
  * Add a new `quoted-strings` rule
- Changes file fix
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 0.11.1
  * Handle merge keys (`<<`) in the `key-duplicates` rule
  * Update documentation about pre-commit
  * Make examples for `ignore` rule clearer
  * Clarify documentation on the 'truthy' rule
  * Fix crash in parser due to a change in PyYAML > 3.12
- Update to 1.11.0
  * Add a new `octal-values` rule
- Spec file cleanups
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version
